@@ -17,7 +17,7 @@ Readonly my $REVERSE     => TRUE;
 # Glib::ParamSpec->object in Gscan2pdf::Dialog::Scan
 use Glib::Object::Subclass Glib::Object::;
 
-our $VERSION = '2.6.6';
+our $VERSION = '2.6.7';
 
 my $EMPTY       = q{};
 my $uuid_object = Data::UUID->new;
@@ -165,6 +165,9 @@ sub get_frontend_option {
 sub remove_frontend_option {
     my ( $self, $name ) = @_;
     delete $self->{data}{frontend}{$name};
+    if ( not keys %{ $self->{data}{frontend} } ) {
+        delete $self->{data}{frontend};
+    }
     return;
 }
 
